if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt