export CONDA_BUILD="1"
export PYTHONNOUSERSITE="1"
export CONDA_DEFAULT_ENV="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho"
export ARCH="64"
export PREFIX="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho"
export BUILD_PREFIX="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_build_env"
export SYS_PREFIX="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/build_env"
export SYS_PYTHON="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/build_env/bin/python"
export SUBDIR="osx-64"
export build_platform="osx-64"
export SRC_DIR="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/work"
export ROOT="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/build_env"
export CONDA_PY="39"
export PY3K="1"
export PY_VER="3.9"
export STDLIB_DIR="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/lib/python3.9"
export SP_DIR="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/lib/python3.9/site-packages"
export PYTHON="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/bin/python"
export NPY_VER="1.16"
export CONDA_NPY="116"
export NPY_DISTUTILS_APPEND_FLAGS="1"
export PERL_VER="5.26"
export CONDA_PERL="5.26"
export LUA_VER="5"
export CONDA_LUA="5"
export R_VER="3.5"
export CONDA_R="3.5"
export PKG_NAME="pymongo"
export PKG_VERSION="3.11.2"
export PKG_BUILDNUM="0"
export PKG_BUILD_STRING="placeholder"
export PKG_HASH="1234567"
export RECIPE_DIR="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/combined_recipe"
export CPU_COUNT="3"
export LC_ALL="en_US.UTF-8"
export SHLIB_EXT=".dylib"
export PATH="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_build_env:/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_build_env/bin:/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho:/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/bin:/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/build_env/bin:/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/build_env/condabin:/opt/conda/bin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin"
export HOME="/var/root"
export PKG_CONFIG_PATH="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho/lib/pkgconfig"
export CMAKE_GENERATOR="Unix Makefiles"
export OSX_ARCH="x86_64"
export MACOSX_DEPLOYMENT_TARGET="10.9"
export BUILD="x86_64-apple-darwin13.4.0"
export ignore_build_only_deps="{'python', 'numpy'}"
export pin_run_as_build="OrderedDict([('python', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('r-base', {'max_pin': 'x.x', 'min_pin': 'x.x'}), ('libboost', {'max_pin': 'x.x.x'})])"
export extend_keys="{'ignore_build_only_deps', 'pin_run_as_build', 'extend_keys', 'ignore_version'}"
export mkl="2019"
export rust_compiler="rust"
export gst_plugins_base="1.14"
export boost="1.73"
export tk="8.6"
export jpeg="9"
export serf="1.3.9"
export libwebp="1.0.0"
export cxx_compiler="clangxx"
export zlib="1.2"
export geos="3.8.0"
export cran_mirror="https://mran.microsoft.com/snapshot/2018-01-01"
export macos_machine="x86_64-apple-darwin13.4.0"
export giflib="5"
export cpu_optimization_target="nocona"
export expat="2.2"
export freetype="2.10"
export macos_min_version="10.9"
export hdfeos5="5.1"
export python_implementation="cpython"
export xz="5"
export hdf5="1.10.6"
export r_implementation="r-base"
export channel_targets="defaults"
export libffi="3.3"
export libtiff="4.1"
export c_compiler_version="10"
export gnu="2.12.2"
export noarch_python="python"
export CONDA_BUILD_SYSROOT="/opt/MacOSX10.10.sdk"
export qtwebkit="true"
export proj="6.2.1"
export blas_impl="openblas"
export cxx_compiler_version="10"
export icu="58"
export rust_compiler_version="1.46.0"
export llvm_variant="llvm"
export libkml="1.3"
export VERBOSE_CM="VERBOSE=1"
export openblas="0.3.3"
export libpng="1.6"
export cyrus_sasl="2.1.26"
export readline="8.0"
export VERBOSE_AT="V=1"
export boost_cpp="1.73"
export dbus="1"
export clang_variant="clang"
export libdap4="3.19"
export libprotobuf="3.11.2"
export lzo="2"
export libgdal="3.0"
export openssl="1.1.1"
export pixman="0.34"
export mpfr="4"
export r_base="3.5"
export proj4="5.2.0"
export gstreamer="1.14"
export fontconfig="2.13"
export gmp="6.1"
export nodejs="8.12"
export bzip2="1.0"
export libnetcdf="4.6"
export libxslt="1.1"
export harfbuzz="2.4"
export hdfeos2="2.20"
export r_version="3.5.0"
export target_platform="osx-64"
export python_impl="cpython"
export glib="2"
export g2clib="1.6"
export sqlite="3"
export libgsasl="1.8"
export c_compiler="clang"
export cairo="1.14"
export libgd="2.2.5"
export libxml2="2.9"
export openjpeg="2.3"
export apr="1.6.3"
export hdf4="4.2"
export fortran_compiler="gfortran"
export CONDA_BUILD_STATE="BUILD"
export PIP_NO_BUILD_ISOLATION="False"
export PIP_NO_DEPENDENCIES="True"
export PIP_IGNORE_INSTALLED="True"
export PIP_CACHE_DIR="/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/pip_cache"
export PIP_NO_INDEX="True"
eval "$('/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/build_env/bin/python' -m conda shell.bash hook)"
conda activate "/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeho"
conda activate --stack "/opt/concourse/worker/volumes/live/b58aa44b-24a7-415d-63c5-dbfb22c5d7d2/volume/pymongo_1607369026266/_build_env"
